@@ -791,6 +791,16 @@ module Command
     end
   end
 
+  # Same as:
+  #   h = Bio::Command.new_http(address, port)
+  #   h.use_ssl = true
+  #   h
+  def new_https(address, port = 443)
+    connection = new_http(address, port)
+    connection.use_ssl = true
+    connection
+  end
+
   # Same as:
   #  http = Net::HTTP.new(...); http.post_form(path, params)
   # and 
