@@ -8,7 +8,6 @@
 #              2008  Naohisa Goto <ng@bioruby.org>
 # License::    The Ruby License
 #
-# $Id:$
 #
 require 'uri'
 require 'strscan'
@@ -236,10 +235,10 @@ module Bio
           CHAR2BACKSLASH.merge({ '"' => '"', "\\" => "\\" }).freeze
 
         # prohibited characters in GFF2 columns
-        PROHIBITED_GFF2_COLUMNS = /[\t\r\n\x00-\x1f\x7f\xfe\xff]/
+        PROHIBITED_GFF2_COLUMNS = /[\t\r\n\x00-\x08\x0b\x0c\x0e-\x1f\x7f\xfe\xff]/
 
         # prohibited characters in GFF2 attribute tags
-        PROHIBITED_GFF2_TAGS = /[\s\"\;\t\r\n\x00-\x1f\x7f\xfe\xff]/
+        PROHIBITED_GFF2_TAGS = /[\s\"\;\x00-\x08\x0e-\x1f\x7f\xfe\xff]/
 
         private
         # (private) escapes GFF2 free text string
@@ -1066,7 +1065,7 @@ module Bio
 
         # parses given string and returns SequenceRegion class
         def self.parse(str)
-          dummy, seqid, start, endpos =
+          _, seqid, start, endpos =
             str.chomp.split(/\s+/, 4).collect { |x| unescape(x) }
           self.new(seqid, start, endpos)
         end
