@@ -5,7 +5,6 @@
 #               Diana Jaunzeikare <latvianlinuxgirl@gmail.com>
 # License::     The Ruby License
 #
-# $Id:$
 #
 # == Description
 #
@@ -91,17 +90,17 @@ module PhyloXML
     # Converts elements to xml representation. Called by PhyloXML::Writer class.
     def to_xml
       taxonomy = LibXML::XML::Node.new('taxonomy')
-      taxonomy["type"] = @type if @type != nil
-      taxonomy["id_source"] = @id_source if @id_source != nil
+      taxonomy["type"] = @type if (defined? @type) && @type
+      taxonomy["id_source"] = @id_source if (defined? @id_source) && @id_source
 
-      PhyloXML::Writer.generate_xml(taxonomy, self, [[:complex, 'id', @taxonomy_id],
-        [:pattern, 'code', @code, Regexp.new("^[a-zA-Z0-9_]{2,10}$")],
-        [:simple, 'scientific_name', @scientific_name],
-        [:simple, 'authority', @authority],
-        [:simplearr, 'common_name', @common_names],
-        [:simplearr, 'synonym', @synonyms],
-        [:simple, 'rank', @rank],
-        [:complex, 'uri',@uri]])
+      PhyloXML::Writer.generate_xml(taxonomy, self, [[:complex, 'id', (defined? @taxonomy_id) ? @taxonomy_id : nil],
+        [:pattern, 'code', (defined? @code) ? @code : nil, Regexp.new("^[a-zA-Z0-9_]{2,10}$")],
+        [:simple, 'scientific_name', (defined? @scientific_name) ? @scientific_name : nil],
+        [:simple, 'authority', (defined? @authority) ? @authority : nil],
+        [:simplearr, 'common_name', (defined? @common_names) ? @common_names : nil],
+        [:simplearr, 'synonym', (defined? @synonyms) ? @synonyms : nil],
+        [:simple, 'rank', (defined? @rank) ? @rank : nil],
+        [:complex, 'uri',(defined? @uri) ? @uri : nil]])
         #@todo anything else
 
 
@@ -161,7 +160,7 @@ module PhyloXML
      @other = []
    end
 
- end
+  end
 
 
   # == Description
@@ -287,7 +286,7 @@ module PhyloXML
     def to_xml(branch_length,  write_branch_length_as_subelement)
       clade = LibXML::XML::Node.new('clade')
       
-      PhyloXML::Writer.generate_xml(clade, self, [[:simple, 'name', @name]])
+      PhyloXML::Writer.generate_xml(clade, self, [[:simple, 'name', (defined? @name) ? @name : nil]])
 
       if branch_length != nil       
         if write_branch_length_as_subelement
@@ -301,15 +300,15 @@ module PhyloXML
       PhyloXML::Writer.generate_xml(clade, self, [
           [:attr, "id_source"],
           [:objarr, 'confidence', 'confidences'],
-          [:simple, 'width', @width],
-          [:complex, 'branch_color', @branch_color],
-          [:simple, 'node_id', @node_id],
+          [:simple, 'width', (defined? @width) ? @width : nil],
+          [:complex, 'branch_color', (defined? @branch_color) ? @branch_color : nil],
+          [:simple, 'node_id', (defined? @node_id) ? @node_id : nil],
           [:objarr, 'taxonomy', 'taxonomies'],
           [:objarr, 'sequence', 'sequences'],
-          [:complex, 'events', @events],
-          [:complex, 'binary_characters', @binary_characters],          
+          [:complex, 'events', (defined? @events) ? @events : nil],
+          [:complex, 'binary_characters', (defined? @binary_characters) ? @binary_characters : nil],
           [:objarr, 'distribution', 'distributions'],
-          [:complex, 'date', @date],          
+          [:complex, 'date', (defined? @date) ? @date : nil],
           [:objarr, 'reference', 'references'],
           [:objarr, 'propery', 'properties']])
      
@@ -322,7 +321,7 @@ module PhyloXML
   # Events at the root node of a clade (e.g. one gene duplication).
   class Events
     #value comes from list: transfer, fusion, speciation_or_duplication, other, mixed, unassigned
-    attr_accessor :type
+    attr_reader :type
 
     # Integer
     attr_reader :duplications, :speciations, :losses
@@ -330,26 +329,33 @@ module PhyloXML
     # Confidence object
     attr_reader :confidence
 
-    def confidence=(type, value)
-      @confidence = Confidence.new(type, value)
-    end
+    #---
+    #def confidence=(type, value)
+    #  @confidence = Confidence.new(type, value)
+    #end
+    #+++
 
+    # Confidence object
     def confidence=(conf)
       @confidence = conf
     end
 
+    # Integer
     def duplications=(str)
       @duplications = str.to_i
     end
 
+    # Integer
     def losses=(str)
       @losses = str.to_i
     end
 
+    # Integer
     def speciations=(str)
       @speciations=str.to_i
     end
 
+    #value comes from list: transfer, fusion, speciation_or_duplication, other, mixed, unassigned
     def type=(str)
       @type = str
       #@todo add unit test for this
@@ -363,11 +369,11 @@ module PhyloXML
       #@todo add unit test
       events = LibXML::XML::Node.new('events')
       PhyloXML::Writer.generate_xml(events, self, [
-        [:simple, 'type', @type],
-        [:simple, 'duplications', @duplications],
-        [:simple, 'speciations', @speciations],
-        [:simple, 'losses', @losses],
-        [:complex, 'confidence', @confidence]])
+        [:simple, 'type', (defined? @type) ? @type : nil],
+        [:simple, 'duplications', (defined? @duplications) ? @duplications : nil],
+        [:simple, 'speciations', (defined? @speciations) ? @speciations : nil],
+        [:simple, 'losses', (defined? @losses) ? @losses : nil],
+        [:complex, 'confidence', (defined? @confidence) ? @confidence : nil]])
       return events
     end
 
@@ -437,13 +443,13 @@ module PhyloXML
     # 'map datum'), for example Google's KML uses 'WGS84'.
     class Point
       # Float. Latitude
-      attr_accessor :lat
+      attr_reader :lat
 
       # Float. Longitute
-      attr_accessor :long
+      attr_reader :long
       
       # Float. Altitude
-      attr_accessor :alt
+      attr_reader :alt
 
       # String. Altitude unit.
       attr_accessor :alt_unit
@@ -451,14 +457,17 @@ module PhyloXML
       # Geodedic datum / map datum
       attr_accessor :geodetic_datum
 
+      # Float. Latitude
       def lat=(str)
         @lat = str.to_f unless str.nil?
       end
 
+      # Float. Longitute
       def long=(str)
         @long = str.to_f unless str.nil?
       end
 
+      # Float. Altitude
       def alt=(str)
         @alt = str.to_f unless str.nil?
       end
@@ -581,7 +590,7 @@ module PhyloXML
       def to_xml
         
         seq = LibXML::XML::Node.new('sequence')
-        if @type != nil
+        if (defined? @type) && @type
           if ["dna", "rna", "protein"].include?(@type)
             seq["type"] = @type
           else 
@@ -592,22 +601,22 @@ module PhyloXML
         PhyloXML::Writer.generate_xml(seq, self, [
             [:attr, 'id_source'],
             [:attr, 'id_ref'],
-            [:pattern, 'symbol', @symbol, Regexp.new("^\\S{1,10}$")],
-            [:complex, 'accession', @accession],
-            [:simple, 'name', @name],
-            [:simple, 'location', @location]])
+            [:pattern, 'symbol', (defined? @symbol) ? @symbol : nil, Regexp.new("^\\S{1,10}$")],
+            [:complex, 'accession', (defined? @accession) ? @accession : nil],
+            [:simple, 'name', (defined? @name) ? @name : nil],
+            [:simple, 'location', (defined? @location) ? @location : nil]])
 
-        if @mol_seq != nil
+        if (defined? @mol_seq) && @mol_seq
           molseq = LibXML::XML::Node.new('mol_seq', @mol_seq)
-          molseq["is_aligned"] = @is_aligned.to_s if @is_aligned != nil
+          molseq["is_aligned"] = @is_aligned.to_s if (defined? @is_aligned) && @is_aligned != nil
           seq << molseq
         end
 
         PhyloXML::Writer.generate_xml(seq, self, [
             #[:pattern, 'mol_seq', @mol_seq, Regexp.new("^[a-zA-Z\.\-\?\*_]+$")],
-            [:complex, 'uri', @uri],
+            [:complex, 'uri', (defined? @uri) ? @uri : nil],
             [:objarr, 'annotation', 'annotations'],
-            [:complex, 'domain_architecture', @domain_architecture]])
+            [:complex, 'domain_architecture', (defined? @domain_architecture) ? @domain_architecture : nil]])
             #@todo test domain_architecture
         #any
         return seq
@@ -626,7 +635,7 @@ module PhyloXML
         # seq.primary_accession = @accession.value could be this
         seq.definition = @name
         #seq.comments = @name //this one?
-        if @uri != nil
+        if (defined? @uri) && @uri
           h = {'url' => @uri.uri,
             'title' => @uri.desc }
           ref = Bio::Reference.new(h)
@@ -720,11 +729,11 @@ module PhyloXML
       # Converts elements to xml representation. Called by PhyloXML::Writer class. 
       def to_xml
         annot = LibXML::XML::Node.new('annotation')
-        annot["ref"] = @ref if @ref != nil
-        PhyloXML::Writer.generate_xml(annot, self, [[:simple, 'desc', @desc],
-          [:complex, 'confidence', @confidence],
+        annot["ref"] = @ref if (defined? @ref) && @ref
+        PhyloXML::Writer.generate_xml(annot, self, [[:simple, 'desc', (defined? @desc) ? @desc : nil],
+          [:complex, 'confidence', (defined? @confidence) ? @confidence : nil],
           [:objarr, 'property', 'properties'],
-          [:complex, 'uri', @uri]])
+          [:complex, 'uri', (defined? @uri) ? @uri : nil]])
         return annot
       end
     end
@@ -825,10 +834,10 @@ module PhyloXML
         date = LibXML::XML::Node.new('date')
         PhyloXML::Writer.generate_xml(date, self, [
             [:attr, 'unit'],
-            [:simple, 'desc', @desc],
-            [:simple, 'value', @value],
-            [:simple, 'minimum', @minimum],
-            [:simple, 'maximum', @maximum]])
+            [:simple, 'desc', (defined? @desc) ? @desc : nil],
+            [:simple, 'value', (defined? @value) ? @value : nil],
+            [:simple, 'minimum', (defined? @minimum) ? @minimum : nil],
+            [:simple, 'maximum', (defined? @maximum) ? @maximum : nil]])
         return date
       end
 
@@ -839,11 +848,12 @@ module PhyloXML
     # 'length' is the total length of the protein
     class DomainArchitecture
       # Integer. Total length of the protein
-      attr_accessor :length
+      attr_reader :length
 
       # Array of ProteinDomain objects.
       attr_reader :domains
 
+      # Integer. Total length of the protein
       def length=(str)
         @length = str.to_i
       end
@@ -868,7 +878,7 @@ module PhyloXML
     # name/unique identifier is described via the 'id' attribute.
     class ProteinDomain
       #Float, for example to store E-values    4.7E-14
-      attr_accessor :confidence
+      attr_reader :confidence
       
       # String
       attr_accessor :id, :value
@@ -879,14 +889,17 @@ module PhyloXML
       # Integer. End of the domain.
       attr_reader :to
 
+      # Integer. Beginning of the domain.
       def from=(str)
         @from = str.to_i
       end
 
+      # Integer. End of the domain.
       def to=(str)
         @to = str.to_i
       end
       
+      #Float, for example to store E-values    4.7E-14
       def confidence=(str)
         @confidence = str.to_f
       end
@@ -901,7 +914,7 @@ module PhyloXML
           xml_node = LibXML::XML::Node.new('domain', @value)
           xml_node["from"] = @from.to_s
           xml_node["to"] = @to.to_s
-          xml_node["id"] = @id if @id != nil
+          xml_node["id"] = @id if (defined? @id) && @id
           xml_node["confidence"] = @confidence.to_s
 
           return xml_node
@@ -987,7 +1000,7 @@ module PhyloXML
         ref = LibXML::XML::Node.new('reference')
         Writer.generate_xml(ref, self, [
               [:attr, 'doi'],
-              [:simple, 'desc', @desc]])
+              [:simple, 'desc', (defined? @desc) ? @desc : nil]])
          return ref
       end
 
@@ -999,7 +1012,7 @@ module PhyloXML
     # For example it could be used to describe multiple parents of a clade.
     class CladeRelation
       # Float
-      attr_accessor :distance
+      attr_reader :distance
       # String. Id of the referenced parents of a clade.
       attr_accessor :id_ref_0, :id_ref_1
       # String
@@ -1007,6 +1020,7 @@ module PhyloXML
       # Confidence object
       attr_accessor :confidence
 
+      # Float
       def distance=(str)
         @distance = str.to_f
       end
@@ -1022,7 +1036,7 @@ module PhyloXML
               [:attr, 'id_ref_1'],
               [:attr, 'distance'],
               [:attr, 'type'],
-              [:complex, 'confidence', @confidnece]])         
+              [:complex, 'confidence', (defined? @confidnece) ? @confidnece : nil]])
 
           return cr
         end
@@ -1107,7 +1121,13 @@ module PhyloXML
     # attribute 'type' is 'orthology').
     class SequenceRelation
       # String
-      attr_accessor :id_ref_0, :id_ref_1, :type
+      attr_accessor :id_ref_0, :id_ref_1
+
+      # String. Allowed values: "orthology", "one_to_one_orthology",
+      # "super_orthology", "paralogy", "ultra_paralogy", "xenology",
+      # "unknown", "other"
+      attr_reader :type
+
       # Float
       attr_reader :distance
 
@@ -1117,6 +1137,9 @@ module PhyloXML
         @distance = str.to_f if str != nil
       end
 
+      # String. Allowed values: "orthology", "one_to_one_orthology",
+      # "super_orthology", "paralogy", "ultra_paralogy", "xenology",
+      # "unknown", "other"
       def type=(str)
         #@todo do warning instead?
         #@todo do validation at actually writing xml
@@ -1137,7 +1160,7 @@ module PhyloXML
           sr = LibXML::XML::Node.new('sequence_relation')
           sr['id_ref_0'] = @id_ref_0
           sr['id_ref_1'] = @id_ref_1
-          sr['distance'] = @distance.to_s if @distance != nil
+          sr['distance'] = @distance.to_s if (defined? @distance) && @distance
           sr['type'] = @type
           return sr
         end
@@ -1145,7 +1168,7 @@ module PhyloXML
 
     end
 
-   class Other
+    class Other
       attr_accessor :element_name, :attributes, :children, :value
       
       def initialize
