@@ -5,7 +5,6 @@
 #               Diana Jaunzeikare <latvianlinuxgirl@gmail.com>
 # License::     The Ruby License
 #
-# $Id:$
 #
 # == Description
 #
@@ -162,6 +161,7 @@ module PhyloXML
         ensure
           obj.close if obj and !obj.closed?
         end
+        ret
       else
         obj
       end
@@ -258,7 +258,7 @@ module PhyloXML
 
       schema = _schema
       begin
-        flag = xml_instance.validate_schema(schema) do |msg, flag|
+        flag = xml_instance.validate_schema(schema) do |msg, _|
           # The document of libxml-ruby says that the block is called
           # when validation failed, but it seems it is never called
           # even when validation failed!
